# R/R/test.R
# 
# R test script
# 
# 
# Copyright (C) 2015. Javier Royuela del Val
#                     Federico Simmross Wattenberg
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; If not, see <http://www.gnu.org/licenses/>.
#
#
#  Javier Royuela del Val.
#  E.T.S.I. Telecomunicación
#  Universidad de Valladolid
#  Paseo de Belén 15, 47002 Valladolid, Spain.
#  jroyval@lpi.tel.uva.es

# Load package
library("libstableR")

# Set parameter vector:
alpha <- 0.75;  # stability index
beta  <- 0.5;   # skew index
sigma <- 1.0;   # scale parameter
mu    <- 0.0;   # location parameter

pars <- c(alpha, beta, sigma, mu)

# abscissae vector
x    <- seq(from=-5, to=10, by=0.01)

# evaluation of pdf and cdf
pdf  <- stable_pdf(x, pars, parametrization=0, tol=1e-12)
cdf  <- stable_cdf(x, pars, parametrization=0, tol=1e-12)

# probabilities vector and quantile function evaluation
p  <- seq(from=0.01, to=0.99, by=0.01)
q  <- stable_q(p, pars, parametrization=0, tol=1e-12)

# Random numbers generation
N   <- 1000;
rnd <- stable_rnd(N, pars, seed=1234)

# Parameter estimation with Koutrouvelis method.
# McCulloch estimator will be used for initialization.
pars_est_1 <- stable_fit_init(rnd)
print(pars_est_1)

pars_est_2 <- stable_fit_koutrouvelis(rnd, pars_est_1)
print(pars_est_2)

pars_est_3 <- stable_fit_mle(rnd)
print(pars_est_3)

pars_est_4 <- stable_fit_mle2d(rnd, pars_est_1)
print(pars_est_4)

# Evaluate estimated pdf and cdf
pdf_est_1 <- stable_pdf(x, pars_est_1)
pdf_est_2 <- stable_pdf(x, pars_est_2)
pdf_est_3 <- stable_pdf(x, pars_est_3)
pdf_est_4 <- stable_pdf(x, pars_est_4)

plot(x, pdf, 'l', col = "black")
lines(x, pdf_est_1, col="red")
lines(x, pdf_est_2, col="green")
lines(x, pdf_est_3, col="blue")
lines(x, pdf_est_4, col="yellow")

hist(rnd,
         xlim = range(x),
         ylim = range(pdf), 
         freq = FALSE,
         breaks = seq(min(rnd)-1, max(rnd)+1, 0.5) )
lines(x, pdf, col="black")
lines(x, pdf_est_1, col="red")
lines(x, pdf_est_2, col="green")
lines(x, pdf_est_3, col="blue")
lines(x, pdf_est_4, col="yellow")

legend(5, 0.35,
       c("Histogram", "True pdf", "McCulloch", "Koutrouveils","Max. likelihood", "Modified max. likelihood"),
       lty = c(1,1,1,1,1,1),
       lwd = c(2,2,2,2,2,1),
       col=c("black","black","red","green","blue","yellow"))
