# R/R/test.R
# 
# R script to analize stabledist package performance and precisson
# for comparisson with the developed libstable.
# This script can take a long time to run (~10 minutes)
# 
# 
# Copyright (C) 2015. Javier Royuela del Val
#                     Federico Simmross Wattenberg
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 3 of the License.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; If not, see <http://www.gnu.org/licenses/>.
#
#
#  Javier Royuela del Val.
#  E.T.S.I. Telecomunicación
#  Universidad de Valladolid
#  Paseo de Belén 15, 47002 Valladolid, Spain.
#  jroyval@lpi.tel.uva.es

# Store the current directory
# initial.dir<-getwd()
# change to the new directory
# setwd("~/workspace/libstable/R")

# This script depends on the following packages. Please make sure to install them before running it:
library(R.matlab)
library(stabledist)
library(libstableR)

# Do it:
# pars = c(alpha, beta, sigma, mu, [parametrization], [seed])
alpha <- 0.75;
beta  <- 0.5;
sigma <- 1.0;
mu_0  <- 0.0;
pm    <- 0;
seed  <- 1;
subdivisions <-500;

pars <- c(alpha, beta, sigma, mu_0, pm, seed);

# Relative error tolerances array
tol <- c(64*.Machine$double.eps, 1e-12, 1e-10, 1e-8, 1e-6);

# x vector
x    <- seq(from=-40, to=272.46875, by=0.03125);


NTIMES <- 10;

tm_pdf <- matrix(0, length(tol), NTIMES);
tm_cdf <- matrix(0, length(tol), NTIMES);

#loop
for(i in 1:length(tol)) {
  cat(sprintf("\n Tolerance[%d] = %e\n Repetition (of %d): ",i,tol[i], NTIMES))
  
  for(k in 1:NTIMES) {
    cat(sprintf(" %d",k))
    
    aux <- system.time(
    {
      pdf <- dstable(x, alpha, beta, sigma, mu_0, pm, log=FALSE, tol=tol[i], subdivisions<-subdivisions);
    });
    
    tm_pdf[i, k] <- aux[3];
    
    aux <- system.time(
    {
      cdf <- pstable(x, alpha, beta, sigma, mu_0, pm, log=FALSE, tol=tol[i], subdivisions<-subdivisions);
    });
    
    tm_cdf[i, k] <- aux[3];
  }
}

r_pdf = NTIMES/tm_pdf;
r_cdf = NTIMES/tm_cdf;

save(tm_pdf, tm_cdf, r_pdf, r_cdf, file = "../generated_data/performance_R_stabledist.txt", ascii=TRUE);
writeMat("../generated_data/performance_R_stabledist.mat", tm_pdf=tm_pdf, tm_cdf=tm_cdf, r_pdf=r_pdf, r_cdf=r_cdf);

# change back to the original directory
# setwd(initial.dir);
