#!/bin/bash
# Bash script to generate manuscript data

echo    ""
echo    "//=======================================================================\\\\"
echo    "|| BASH SCRIPT TO GENERATE DATA NEEDED TO REPLICATE MANUSTCRIPT RESULTS. ||"
echo    "||=======================================================================||"
echo    "||   Please note that this process may take a long time, especially to   ||"
echo    "||                 obtain Figure 3 and performance data.                 ||"
echo    "||           Precalculated data is available for download at:            ||"
echo    "||      http://www.lpi.tel.uva.es/~jroyval/JSS_1266_Rep_data.tar.gz      ||"
echo  "\\\\=======================================================================//"
echo    ""
echo    " Select data to generate. Multiple can be selected:"
echo    "  1 - Generate libstable data for Table 1"
echo    "  2 - Generate libstable data for Figure 3"
echo    "  3 - Generate performance data for libstable"
echo    "-----------------------------------------------------------------"
echo    "  Example: The input 1 2 3  will run steps 1, 2 and 3 in a row."
echo    "-----------------------------------------------------------------"
read -p "  Select steps and press [ENTER]: " -a SEL
echo    "  In performance benchmarks:"
read -p "      Select how many repetitions and press [ENTER]: " NTEST
echo    "      Select number of threads and press [ENTER]. Example:"
echo    "        enter \"1 2 4\" to perform the benchmark with 1, 2 and 4"
read -p "        threads in a row: " -a THREADS
echo    ""
for i in "${SEL[@]}";
do
  case $i in
    1)
      # Libstable precision data for Table 1
      echo    "  1 - Generate libstable data for Table 1"
      # PDF and CDF
      echo "./libstable/bin/stable_precision 1"
      ./libstable/bin/stable_precision 1
      mv ./libstable_precision_pdf_table_1.txt ./generated_data/
      mv ./libstable_precision_cdf_table_1.txt ./generated_data/
      ;;
    2)
      # Libstable precision data for Figure 3
      echo    "  2 - Generate libstable data for Figure 3"
      echo "./libstable/bin/stable_precision 3"
      ./libstable/bin/stable_precision 3
      mv ./libstable_precision_pdf_figure_3.txt ./generated_data/
      mv ./libstable_precision_cdf_figure_3.txt ./generated_data/
      ;;
    3)
      # Libstable performance benchmark
      echo    "  4 - Generate performance data for libstable"
      for j in "${THREADS[@]}";
      do # PDF benchmark
        echo "./libstable/bin/stable_performance 1 $j $NTEST"
        ./libstable/bin/stable_performance 1 $j $NTEST
        mv ./libstable_performance_pdf_${j}th_${NTEST}test.txt ./generated_data/
      done
      for j in "${THREADS[@]}";
      do # CDF benchmark
        echo "./libstable/bin/stable_performance 2 $j $NTEST"
        ./libstable/bin/stable_performance 2 $j $NTEST
        mv ./libstable_performance_cdf_${j}th_${NTEST}test.txt ./generated_data/
      done
      ;;
  esac
done
