function [thetav, g]=Gright(x, alpha, beta, tau0, tauf, N)
% [thetav, g] = Gright(x, alpha, beta, tau0, tauf, N)
% Auxiliary function to evaluate the integrand of Nolan's expresions to
% calculate the PDF of an \alpha-stable distribution.

[L, M]=size(x);
if(L>1 && M>1)
	disp('x must be scalar or vector');
	return;
end
x=x(:);
M=length(x);
if(alpha==1)
	theta0=0.5*pi;
    thetav=linspace(-theta0+tau0*pi+eps, -theta0+tauf*pi-eps,N);
	
	logV=log(2/pi*(0.5*pi+beta*thetav)./cos(thetav))+((0.5*pi+beta*thetav).*tan(thetav)/beta);
	logg=repmat(logV,M,1)+repmat((-0.5*pi*x/beta),1,N);
    g=exp(logg-exp(logg)); % For PDF integrand
    %g=exp(-exp(logg)); %For CDF integrand
else
	xi=-beta*tan(alpha*pi/2);
	theta0=1/alpha*atan(-xi);
	k1=log(cos(alpha*theta0))*(1/(alpha-1));
	alphainvalpha1=alpha/(alpha-1);
	xxi=x-xi;	
	thetav=linspace(-theta0+tau0*(0.5*pi+theta0)+eps, -theta0+tauf*(0.5*pi+theta0)-eps,N);

    cos_theta=cos(thetav);
	logV=k1 + alphainvalpha1*log(cos_theta./(sin(alpha*(theta0+thetav)))) + log(cos(alpha*theta0+(alpha-1)*thetav)./cos_theta);
	logxxipow=alphainvalpha1.*log(xxi);
	logg=repmat(logV,M,1)+repmat(logxxipow,1,N);
	g=exp(logg-exp(logg));
end

%g(find(isnan(g)))=0;

