function [alpha, beta, x, pdf, cdf] = load_libstable_precision(pdf_filename,cdf_filename)
% txt2mat function for precision test
    
    [x_pdf, a_pdf, b_pdf, pdf] = importdata(pdf_filename);
    [x_cdf, a_cdf, b_cdf, cdf] = importdata(cdf_filename);
    
    if any(x_pdf ~= x_cdf) || any(a_pdf ~= a_cdf) || any(b_pdf ~= b_cdf)
        error('Alpha, beta and x must be the same in PDF and CDF data');
    end
    
    alpha = a_pdf;
    beta  = b_pdf;
    x     = x_pdf;  
end

function [x, alpha, beta, xdf] = importdata(name_xdf)
% Import PDF or CDF data from txt file.

    fid = fopen(name_xdf,'rt');
    if (fid==-1)
        error('no data file');
    end
    
    % Read header with number of points
    H = fscanf(fid,'FUNCTION=%u ALPHAPOINTS=%u BETAPOINTS=%u XPOINTS=%u\n');

    Na=H(2);
    Nb=H(3);
    Nx=H(4);

    alpha = zeros(H(2),1);
    beta  = zeros(H(3),1);
   
    xdf = zeros(Nx,Nb,Na);

    % Iterate over alpha sections in file
    for ia=1:Na
        % Scan alpha value
        alpha(ia)=fscanf(fid,'Alpha = %lf\n',1);
        
        % Scan beta values only for first alpha
%        if ia == 1
            beta(1)=fscanf(fid,'________x\\beta________	%lf',1);
            beta(2:end)=fscanf(fid,'%lf',Nb-1);
%        end

        % Read matrix with x and xdf values
        A = fscanf(fid,'%lf',[Nb+1,Nx]);
        
        % Get x values only for first alpha
%        if ia == 1
            x = A(1,:)';
%        end
        
        % Get xpdf values
        xdf(:,:,ia)=A(2:end,:)';

        % Jump 2 lines
        fgets(fid);
        fgets(fid);
    end

    fclose(fid);
end