function [alpha, beta, tol, t_pdf, t_cdf]=load_nolan_performance(Ntest)
%script de txt2mat para stable_benchmark;

    pdf_filename = sprintf('nolan_performance_pdf_%dtest.txt',Ntest);
    cdf_filename = sprintf('nolan_performance_cdf_%dtest.txt',Ntest);

    [a_pdf, b_pdf, tol_pdf, t_pdf, off_pdf] = importdata(pdf_filename);
    [a_cdf, b_cdf, tol_cdf, t_cdf, off_cdf] = importdata(cdf_filename);
    
    if any(tol_pdf ~= tol_cdf) || any(a_pdf ~= a_cdf) || any(b_pdf ~= b_cdf)
        error('Alpha, beta and x must be the same in PDF and CDF data');
    end
    
    alpha = a_pdf;
    beta  = b_pdf;
    tol   = tol_pdf;
    t_cdf = bsxfun(@minus,t_cdf, off_cdf);
    t_pdf = bsxfun(@minus,t_pdf, off_pdf); 

end

function [alpha, beta, reltol, times, off_time] = importdata(name_xdf)

    fid = fopen(name_xdf,'rt');
    if fid == -1
        error('Error while opening %s file',name);
    end

    Ntol   = fscanf(fid, 'NTOL %d\n',1);
    Ntests = fscanf(fid, 'NTESTS %d\n',1);
    func   = fscanf(fid, 'FUNCTION %d\n',1);
    alpha  = fscanf(fid, 'ALPHA %f\n',1);
    beta   = fscanf(fid, 'BETA %f\n',1);

    for itol=1:Ntol
        reltol(itol)  = fscanf(fid, 'RELTOL %e\n',1);
        times(:,itol) = fscanf(fid,'%f',Ntests);
        fscanf(fid,'\n',1);
    end
    
    fscanf(fid,'OFFSET_TIME\n');
    off_time = fscanf(fid,'%f',Ntests);
    
    fclose(fid);

end