function [alpha, beta, x, pdf, cdf]=load_nolan_precision(pdf_filename,cdf_filename)
%txt2mat script for stable_precision benchmark;
    [x_pdf, a_pdf, b_pdf, pdf] = importdata(pdf_filename);
    [x_cdf, a_cdf, b_cdf, cdf] = importdata(cdf_filename);
    
    if any(x_pdf ~= x_cdf) || any(a_pdf ~= a_cdf) || any(b_pdf ~= b_cdf)
        error('Alpha, beta and x must be the same in PDF and CDF data');
    end
    
    alpha = a_pdf;
    beta  = b_pdf;
    x     = x_pdf;  
end

function [x, alpha, beta, xdf] = importdata(name_xdf)

    fid = fopen(name_xdf,'rt');
    if (fid==-1)
        error('no data file');
    end
    
    % Read header with number of points
    H = fscanf(fid,'FUNCTION=%u ALPHAPOINTS=%u BETAPOINTS=%u XPOINTS=%u\n');

    Na=H(2);
    Nb=H(3);
    Nx=H(4);
    Ndiv = 7;

    alpha = zeros(H(2),1);
    beta  = zeros(H(3),1);
    x     = zeros(H(4),1);
   
    xdf = zeros(Nx,Nb,Na);
    
    pattern = '          x                         beta';
    
    for ia=1:Na
        Nx0=0;
        for ix=1:Ndiv
            line=fgets(fid);
            while (~strcmpi(line(1:end-2),pattern))
                line=fgets(fid);
            end

            alpha(ia) = fscanf(fid,' %lf',1);
            fgets(fid);
            beta = fscanf(fid,'%lf',Nb);

            H = fscanf(fid,'%lf',[Nb+1,Nx]);
            Nxdiv = size(H,2);

            x(Nx0+(1:Nxdiv)) = H(1,:)';
            xdf(Nx0+(1:Nxdiv),:,ia) = H(2:end,:)';
            Nx0 = Nx0 + Nxdiv;
        end
    end

    fclose(fid);
    
end