% Exmple script that includes the example of usage of Libstable from MATLAB
%
% Copyright (C) 2013. Javier Royuela del Val
%                     Federico Simmross Wattenberg

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; version 3 of the License.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; If not, see <http://www.gnu.org/licenses/>.
%
%
%  Javier Royuela del Val.
%  E.T.S.I. Telecomunicación
%  Universidad de Valladolid
%  Paseo de Belén 15, 47002 Valladolid, Spain.
%  jroyval@lpi.tel.uva.es    
%

clear

% Add matlab front-end path
addpath('../../libstable/matlab');

% Some no problematic warnings will appear when loading library.
% Only those are switched off.
warning('off','MATLAB:loadlibrary:parsewarnings');
warning('off','MATLAB:loadlibrary:TypeNotFoundForStructure');
warning('off','MATLAB:loadlibrary:FunctionNotFound');
warning('off','MATLAB:loadlibrary:InvalidFunctionReturnType');

loadlibrary('libstable','stable.h');

x = -5:.1:5;
q = .005:.01:.995;
pars = [1.5, .5, .5, -1.0];
parametrization = 0;

pdf = stable_pdfC(x, pars, parametrization);
cdf = stable_cdfC(x, pars, parametrization);
inv = stable_invC(x, pars, parametrization);

N = 500;
rnd = stable_rndC(N, pars, parametrization, 1234);

p_est = stable_fit_koutrouvelisC(rnd);
disp(p_est);

unloadlibrary('libstable');

warning('on','MATLAB:loadlibrary:parsewarnings');
warning('on','MATLAB:loadlibrary:TypeNotFoundForStructure');
warning('on','MATLAB:loadlibrary:FunctionNotFound');
warning('on','MATLAB:loadlibrary:InvalidFunctionReturnType');