% function figure_1()
% figure_1:
% This function generates the figure 1 in the manuscript.
%
% Copyright (C) 2013. Javier Royuela del Val
%                     Federico Simmross Wattenberg

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; version 3 of the License.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; If not, see <http://www.gnu.org/licenses/>.
%
%
%  Javier Royuela del Val.
%  E.T.S.I. Telecomunicación
%  Universidad de Valladolid
%  Paseo de Belén 15, 47002 Valladolid, Spain.
%  jroyval@lpi.tel.uva.es    
%

clear

addpath('aux/', 'aux/matlab_exportfig/');
set(0,'defaulttextinterpreter','latex');

% Choose alpha and beta by setting ai and bi
a=[0.75 1 1.5];
b=[0 0.5 1];

ai=3;
bi=2;

alpha=a(ai);
beta=b(bi);

% Precompute theta0 and xi ($\zeta$ in the manuscript)
if(alpha==1)
    xi=0;
    theta0=0.5*pi;
else
    xi=-beta*tan(alpha*0.5*pi);
    theta0=atan(-xi)/alpha;
end

% seven x points are choosen depending on alpha and beta
x_ab=zeros(7,length(alpha),length(beta));

x_ab(:,1,1) = xi+(1:7);
x_ab(:,1,2) = [-1 -0.5 0 1.5 5 12 38];
x_ab(:,1,3) = [-1.5 -1 -0.5 0 2 8 25];

x_ab(:,2,1) = xi+(1:7);
x_ab(:,2,2) = xi+(1:7)-3.5;
x_ab(:,2,3) = xi+(1:7);

x_ab(:,3,1) = [-0.8 -0.6 -0.1 0.5 1.5 2 4];
x_ab(:,3,2) = [0.51 0.6 1 1.5 2.5 7 32];
x_ab(:,3,3) = xi+(1:7);


% x xhoosen
x=x_ab(:,ai,bi);

Nx=length(x);

% Number of evaluations of each integrand
Nth=10000;

% Evaluate the integrands with auxiliary function
[theta, g]=Gright(x,alpha,beta,eps,1-eps,Nth);

% Locate maximum of each integrand to place text label
theta2=zeros(size(x)); % max position
lin=zeros(length(x));  % integrand value an maximum
for k=1:Nx
    try
        % Search maximum in integration interval. Use auxiliary function.
        theta2(k)=fzero(@(theta) nolang_aux(theta, x(k), alpha, beta, theta0, xi),[-theta0+0.001 0.5*pi-0.001]);
    catch
        % In some cases, maximum will be in one extreme of the interval
        disp(-theta0+0.3*(k+2));
        if alpha>1 || (alpha==1 && beta < 0)
            theta2(k)=0.5*pi-0.1*(Nx-k+0.75);
        else
            theta2(k)=-theta0+0.12*(k);
        end
    end
    % Evaluate integrand at its maximum
    z=nolang_aux(theta2(k), x(k), alpha, beta, theta0, xi);
    lin(k)=exp(z-exp(z));    
end

% Plot figure
Col = colormap('lines');

figure(1);
clf;
set(gcf,'PaperUnits','inches');

% Linear scale
subplot(211)
plot(theta,g,'-');
hold on;
for k=1:Nx
    % Place text labels
    text(theta2(k),exp(-1)+0.015,['$x=' num2str(x(k),'% g') '$'], ...
         'HorizontalAlignment','left',...
         'VerticalAlignment','middle',...
         'Rotation',90);
    line([theta2(k),theta2(k)],[exp(-1)+0.0075 lin(k)],...
         'LineStyle','--',...
         'Color',Col(k,:));
end
%set(gca,'xtick',-1.5:0.5:1.5);
h(1) = gca;
set(h(1), 'ytick',0:0.1:0.5);
set(h(1), 'xticklabel',{});
xlim([-theta0-0.05 0.5*pi+0.05]);
ylim([0 0.55]);
ylabel('$h_{\alpha,\beta)}(\theta;x)$');

subplot(212)
semilogy(theta,g);
h(2)=gca;
set(h(2),'ytick',[1e-15 1e-10 1e-5]);
xlabel('$\theta$');
ylabel('$\log_{10}(h_{\alpha,\beta)}(\theta;x))$');
xlim([-theta0-0.05 0.5*pi+0.05]);
ylim([1e-16 1.5]);

% Linaxes
linkaxes(h,'x');

% Exportfig options
OPT=struct('Bounds','tight',...
           'Color' ,'rgb'  ,...
           'Width' ,'2.84'    ,...
           'FontEncoding','latin1',...
           'FontMode'    ,'fixed',...
           'FontSize'    ,'7',...
           'LockAxes'    ,'0');


%exportfig(1,['./g_' num2str(alpha) '_' num2str(beta) '_lin.eps'],OPT,'Height',2.5)%,'Reference',h(1))

% end
