% function figure_2()
% figure_2:
% This function generates the figure 2 in the manuscript, with an example
% of the subdivision of the integration interval.
%
% Copyright (C) 2013. Javier Royuela del Val
%                     Federico Simmross Wattenberg

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; version 3 of the License.
% 
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; If not, see <http://www.gnu.org/licenses/>.
%
%
%  Javier Royuela del Val.
%  E.T.S.I. Telecomunicación
%  Universidad de Valladolid
%  Paseo de Belén 15, 47002 Valladolid, Spain.
%  jroyval@lpi.tel.uva.es    
%

clear

addpath('aux/','aux/matlab_exportfig/');
set(0,'defaulttextinterpreter','latex');

% Set alpha, beta, and x:
alpha=1.5;
beta=0.5;
x=6;

% Set relative error tolerance:
TOL=-8;

% Auxiliar values for the location of threshold values:
auxa=log(-log(10^TOL/8.5358)/0.9599);
auxb=TOL*log(10);

if alpha<1
    auxb=auxa;
    auxa=TOL*log(10);
end

% Precomputed values:
if(alpha==1)
    xi=0;
    theta0=0.5*pi;
    invalpha1=beta;
    alphainvalpha1=0;
else
    xi=-beta*tan(alpha*0.5*pi);
    theta0=atan(-xi)/alpha;
    invalpha1=1/(alpha-1);
    alphainvalpha1=alpha*invalpha1;
end

% Number of integrand evaluations
Nth=1000;

% Evaluation of the inegrand
[theta, h] = Gright(x,alpha,beta,10*eps,1-10*eps,Nth);

% Auxiliar function
logg=nolang_aux(theta, x, alpha, beta, theta0, xi);

%   a) The maximum of the integrand
%   b) The points where the integrand falls below some threshold.
flag=0;
try
    theta2=fzero(@(th) nolang_aux(th,x,alpha,beta,theta0,xi),[-theta0+50*eps 0.5*pi-50*eps]);
catch me
    if alpha>1 || (alpha==1 && beta < 0)
        flag=1;
        theta2=0.5*pi-50*eps;
    else
        flag=-1;
        theta2=-theta0+50*eps;
    end
end

if flag==1
    z=nolang_aux(theta2,x,alpha,beta,theta0,xi); %z=exp(z-exp(z));
    thetaa = fzero(@(th) nolang_aux_mod(th,z+1.1,x,alpha,xi,theta0,invalpha1,alphainvalpha1),[-theta0+50*eps theta2]);
    z=nolang_aux(thetaa,x,alpha,beta,theta0,xi); %z=exp(z-exp(z));
    thetab = fzero(@(th) nolang_aux_mod(th,z+1.35,x,alpha,xi,theta0,invalpha1,alphainvalpha1),[-theta0+50*eps thetaa]);
    theta3 = -pi;
    c=find(thetaa<=theta & theta<=0.5*pi);
    theta_1=theta(c);
    h_1=h(c);
    
    c=find(thetab<=theta & theta<=thetaa);
    theta_2=theta(c);
    h_2=h(c);
else
    try
        thetaa=fzero(@(th) nolang_aux_mod(th,auxa,x,alpha,xi,theta0,invalpha1,alphainvalpha1),[-theta0+eps theta2]);
    catch me
        thetaa=-theta0+50*eps;
    end
    try
        thetab=fzero(@(th) nolang_aux_mod(th,auxb,x,alpha,xi,theta0,invalpha1,alphainvalpha1),[theta2 0.5*pi-eps]);
    catch me
        thetab=0.5*pi-50*eps;
    end

    if theta2-thetaa < thetab-theta2
        theta3=2*theta2-thetaa;
        c=find(thetaa<=theta & theta<=theta3);
        if ~isempty(c) && c(1)>1
            c=[c(1)-1 c];
        end
        theta_1=theta(c);
        h_1=h(c);
        c=find(theta3<=theta & theta<=thetab);
        if ~isempty(c) && c(end)<length(c)
            c=[c c(end)+1];
        end
        theta_2=theta(c);
        h_2=h(c);
    else
        theta3=2*theta2-thetab;
        c=find(theta3<theta & theta<=thetab);
        if ~isempty(c) && c(1)>1
            c=[c(1)-1 c];
        end
        theta_1=theta(c);
        h_1=h(c);
        c=find(thetaa<=theta & theta<=theta3);
        if ~isempty(c) && c(end)<length(c)
            c=[c c(end)+1];
        end
        theta_2=theta(c);
        h_2=h(c);
    end
end

z(1)=nolang_aux(theta2-100*eps,x,alpha,beta,theta0,xi);
z(2)=nolang_aux(thetaa,x,alpha,beta,theta0,xi);
z(3)=nolang_aux(thetab,x,alpha,beta,theta0,xi);
z(4)=nolang_aux(theta3,x,alpha,beta,theta0,xi);
theta_=[theta2 thetaa thetab theta3];

% Integrand in linear scale.
lin=exp(z-exp(z));

lv=zeros(4,3);
lh=zeros(4,2);

% Plot figure
Col=colormap('lines');
collin={'ko','ko','ko','ko'};

figure(2);clf;

%%% Linear scale %%%
a(1)=axes('position',[0.13 0.475 0.85 0.4]);
ar(1)=area(theta_1,h_1);
hold on
ar(2)=area(theta_2,h_2);
set(ar(1),'FaceColor',[0.75 0.75 0.75],'EdgeColor','none');
set(ar(2),'FaceColor',[0.9 0.9 0.9],'EdgeColor','none');
plot(a(1),theta,h,'LineWidth',2);
for i=1:4
    plot(theta_(i),lin(i),collin{i})
    lv(i,2)=line(theta_(i)*[1 1],[-10 lin(i)]);
end

set(a(1),'xticklabel',{});
set(a(1),'ytick',[0, 0.1, 0.2,0.3])
ety=ylabel(a(1),'$h_{\alpha,\beta}(\theta;x)$');

ylim(a(1),[0 0.4]);

%%% Log scale
a(2)=axes('position',[0.13 0.07 0.85 0.4]);
axis(a(2),[-theta0, 1.6 -20 0]);
ar(1)=area(theta_1,log10(h_1));
hold on
ar(2)=area(theta_2,log10(h_2));
set(ar(1),'FaceColor',[0.75 0.75 0.75],'EdgeColor','none','BaseValue',-10);
set(ar(2),'FaceColor',[0.9 0.9 0.9],'EdgeColor','none','BaseValue',-10.01);
plot(a(2),theta,log10(h),'Color',[0 0.5 0],'LineWidth',2);
for i=1:4
    plot(theta_(i),log10(lin(i)),collin{i})
    lv(i,3)=line(theta_(i)*[1 1],[-10 z(i)]);
end
lh(5)=line([-10 10],TOL*[1 1]);

ylabel(a(2),'$\log_{10}(h_{\alpha,\beta}(\theta;x))$')
xlabel(a(2),'$\theta$');
set(a(2),'ytick',[-10, -8, -6,-4,-2])
%tick2text(a(3),'axis','y','yformat',@(x)sprintf('10^{%g}',x),'panon',0,'ytickoffset',0.0);
ylim(a(2),[-10 0]);

%text(theta_+[-0.1 0.04 +0.02 -0.12],[-9 -9 -9 -9],{'\theta_{máx}';'\theta_1';'\theta_2';'\theta_3'});
text(theta_+[-0.06 +0.02 -0.02 -0.07],[-9 -9 -9 -9],{'$\theta_{max}$';'$\theta_1$';'$\theta_2$';'$\theta_3$'});
text(-theta0+0.15,-7.2,'$\epsilon_{rel}$');
%text(theta_+[-0.15 +0.02 +0.02 -0.07],[-9 -9 -9 -9],{'\theta_{máx}';'\theta_1';'\theta_2';'\theta_3'});

linkaxes(a,'x');
title(a(1),['$\alpha=' num2str(alpha) ', \beta=' num2str(beta) ', x=' num2str(x) '$']);

despla=get(ety,'Position')+[0 -0.15 0];
set(ety,'Position',despla);

W=1;
set(lv(1,2:end),'Color','k','LineStyle','--','LineWidth',W);
set(lv(2,2:end),'Color','k','LineStyle','--','LineWidth',W);
set(lv(3,2:end),'Color','k','LineStyle','--','LineWidth',W);
set(lv(4,2:end),'Color','k','LineStyle','--','LineWidth',W);
set(lh(5),'Color','k','LineStyle','--','LineWidth',W);

xlim([-theta0-0.03 1.6]);

% end